
### **Tagebuch – Tag 1**  

**Datum:** *31.01.2025*  
**Thema:** Einführung & Setup  


#### **1. Projektstruktur in GitLab**

- Projektordner gemäß Vorgaben erstellt (Namen, Klasse, Modul, Datum, Version).
- Erste Strukturierung vorgenommen.


#### **2. Erste Inhalte erarbeitet**

- **Kurze Beschreibung zu Containern:**
  - Container sind leichtgewichtige, isolierte Umgebungen zur Ausführung von Anwendungen.
  - Sie enthalten alle notwendigen Abhängigkeiten, um eine Anwendung unabhängig von der Umgebung laufen zu lassen.
  - Container sind besonders nützlich für die Skalierung von Anwendungen und vereinfachen die Bereitstellung in verschiedenen Umgebungen.
  - Sie bieten eine konsistente Laufzeitumgebung und vermeiden das "Funktioniert auf meinem Rechner"-Problem.
  - Besonders praktisch in DevOps, da sie Automatisierung und CI/CD-Pipelines erleichtern.
  - Container können schnell erstellt, dupliziert und gelöscht werden, was die Entwicklungs- und Testprozesse beschleunigt.

- **Kurze Beschreibung zu DevOps:**
  - DevOps ist eine Kultur und eine Sammlung von Praktiken zur Verbesserung der Zusammenarbeit zwischen Entwicklern und IT-Betriebsteams.
  - Ziel ist es, Software schneller, stabiler und effizienter bereitzustellen.
  - Automatisierung, kontinuierliche Integration (CI) und kontinuierliche Bereitstellung (CD) sind zentrale Konzepte.
  - DevOps nutzt Tools wie Docker, Kubernetes, CI/CD-Pipelines (z. B. Jenkins, GitLab CI/CD) und Monitoring-Lösungen.
  - Durch Automatisierung können Fehler minimiert und wiederholbare Prozesse geschaffen werden.
  
- **Unterschied zwischen Virtualisierung und Containerisierung:**
  - Virtualisierung verwendet virtuelle Maschinen (VMs) mit einem eigenen Betriebssystem pro Instanz.
  - Containerisierung nutzt Container, die auf einem gemeinsamen Betriebssystem-Kernel basieren, wodurch sie leichter und schneller sind.
  - VMs sind schwergewichtiger, haben mehr Overhead und sind langsamer zu starten.
  - Container sind effizienter in der Ressourcennutzung und bieten bessere Skalierbarkeit.
  - Während VMs eine vollständige Emulation eines Computers ermöglichen, fokussieren sich Container auf die Anwendungsebene.

- **Unterschied zwischen Image und Container:**
  - **Image:** Eine Vorlage für Container, enthält das Betriebssystem, Anwendungen und Abhängigkeiten.
  - **Container:** Eine laufende Instanz eines Images.
  - Images sind unveränderlich, während Container dynamisch zur Laufzeit genutzt und verändert werden können.
  - Container können aus demselben Image mehrfach instanziiert werden.
  - Ein Image ist vergleichbar mit einer Blaupause, während ein Container das tatsächliche Gebäude ist.

#### **3. Wichtige Befehle**

* `docker pull onlyoffice/documentserver` → Lädt das OnlyOffice-Image herunter.
* `docker ps` → Listet laufende Container auf.
* `docker ps -a` → Zeigt alle Container, auch gestoppte.
* `docker create <image>` → Erstellt einen Container, aber startet ihn nicht.
* `docker start <container_id>` → Startet einen gestoppten Container.
* `docker stop <container_id>` → Stoppt einen laufenden Container.
* `docker restart <container_id>` → Startet einen Container neu.
* `docker rm <container_id>` → Löscht einen gestoppten Container.
* `docker rmi <image>` → Löscht ein Image.
* `docker logs <container_id>` → Zeigt Logs eines Containers an.
* `docker inspect <container_id>` → Zeigt detaillierte Infos zu einem Container.
* `docker exec -it <container_id> /bin/bash` → Öffnet eine Shell innerhalb eines Containers.
* `docker exec -it <container_id> sh` → Öffnet eine interaktive Shell im Container.
* `ip a` → Zeigt die IP-Adresse der VM an.
* `mkdir /app` → Erstellt das benötigte Verzeichnis auf dem Host.
* `chown vmadmin /app` → Setzt die Berechtigungen für den Ordner.
* `docker build -t todo-app:v1 .` → Baut das Docker-Image für die Todo-App.
* `docker build -t redis-slave:v1 .` → Baut das Docker-Image für Redis-Slave.
* `docker build -t redis-master:v1 .` → Baut das Docker-Image für Redis-Master.
* `docker network create todoapp_network` → Erstellt ein Docker-Netzwerk.
* `docker run --net=todoapp_network --name=redis-master -d redis-master:v1` → Startet den Redis-Master-Container.
* `docker run --net=todoapp_network --name=redis-slave -d redis-slave:v1` → Startet den Redis-Slave-Container.
* `docker run --net=todoapp_network --name=frontend -d -p 3000:3000 todo-app:v1` → Startet den Frontend-Container und mappt Port 3000.





![Screenshot](image-1.png)