# Tagebucheintrag Tag 2

## Thema: Dockerfiles und Image Pushing

### **Dockerfiles verstehen und anwenden**
Heute haben wir uns intensiv mit Dockerfiles beschäftigt. Dabei haben wir gelernt, wie ein Docker-Image Schritt für Schritt aufgebaut wird und welche Befehle dabei genutzt werden.

Ein Dockerfile besteht aus verschiedenen Anweisungen:
- **FROM alpine:3.16.2** → Basis-Image auswählen
- **MAINTAINER** → Autor der Datei angeben
- **COPY** → Dateien in das Image kopieren
- **RUN chmod +x** → Datei ausführbar machen
- **WORKDIR** → Arbeitsverzeichnis setzen
- **CMD** → Anwendung starten
- **EXPOSE** → Port freigeben

Nach dem Studium des Dockerfiles für die Todo-App haben wir das Image gebaut und getestet.

**Befehl zum Erstellen des Images:**
```bash
docker image build -t todo-app:v1 .
```

**Befehl zum Starten des Containers:**
```bash
docker run --name frontend -d -p 3000:3000 todo-app:v1
```

---

### **Containerisierte Anwendung mit Redis-Master und Redis-Slave**
Um unsere Anwendung mit einer NoSQL-Datenbank zu betreiben, haben wir Redis als Master-Slave-Konfiguration verwendet. Dazu haben wir die beiden Datenbankserver als Container erstellt.

**Befehle zum Erstellen der Images:**
```bash
docker build -t redis-slave:v1 .
docker build -t redis-master:v1 .
```

**Docker-Netzwerk erstellen:**
```bash
docker network create todoapp_network
```

**Befehle zum Starten der Container:**
```bash
docker run --net=todoapp_network --name=redis-master -d redis-master:v1
docker run --net=todoapp_network --name=redis-slave -d redis-slave:v1
docker run --net=todoapp_network --name=frontend -d -p 3000:3000 todo-app:v1
```

Nach diesen Schritten lief die Todo-App mit den verbundenen Datenbankcontainern.

---

### **Ein Image pushen**
Damit unsere Images gesichert und für zukünftige Nutzung verfügbar sind, haben wir sie in ein Repository hochgeladen.




**Schritt 2: Images neu taggen** (Docker-ID anpassen)
```bash
docker image tag redis-master:v1 staubth/redis-master:v1
docker image tag redis-slave:v1 staubth/redis-slave:v1
docker image tag todo-app:v1 staubth/todo-app:v1
```


**Alternative: Pushen nach GitLab**
```bash
docker login git-registry.gibb.ch
docker image tag redis-master:v1 git-registry.gibb.ch/mha146039/m347-images/redis-master:v1
docker image tag redis-slave:v1 git-registry.gibb.ch/mha146039/m347-images/redis-slave:v1
docker image tag todo-app:v1 git-registry.gibb.ch/mha146039/m347-images/todo-app:v1

docker push git-registry.gibb.ch/mha146039/m347-images/redis-master:v1
docker push git-registry.gibb.ch/mha146039/m347-images/redis-slave:v1
docker push git-registry.gibb.ch/mha146039/m347-images/todo-app:v1
```

---

### **App Version 2 - Frontend aktualisieren**
Als nächstes haben wir das Frontend auf die neue Version (v2) aktualisiert. Die Datenbanken bleiben unverändert.

**Schritt 1: Neue Version herunterladen**
```bash
git clone https://git.gibb.ch/thomas.staub/cloudmodule/-/tree/main/to-do-appv2
```

**Schritt 2: Neues Frontend-Image bauen**
```bash
docker image build -t todo-app:v2 .
```

**Schritt 3: Container mit neuer Version starten**
```bash
docker run --net=todoapp_network --name=frontend -d -p 3000:3000 todo-app:v2
```

**Schritt 4: Neue Version pushen**
```bash
docker image tag todo-app:v2 git-registry.gibb.ch/mha146039/m347-images/todo-app:v2
docker image tag redis-master:v1 git-registry.gibb.ch/mha146039/m347-images/redis-master:v2
docker image tag redis-slave:v1 git-registry.gibb.ch/mha146039/m347-images/redis-slave:v2
docker push git-registry.gibb.ch/mha146039/m347-images/todo-app:v2
docker push git-registry.gibb.ch/mha146039/m347-images/redis-master:v2
docker push git-registry.gibb.ch/mha146039/m347-images/redis-slave:v2
```

---

### **Ergebnisdokumentation**
1. **PrintScreen von Version 1 der App mit eigenem Namen als Todo-Task** ✅
2. **PrintScreen der Images in GitLab (Version 1)** ✅
3. **PrintScreen von Version 2 der App mit eigenem Namen als Todo-Task** ✅
4. **PrintScreen der Images in GitLab (Version 2)** ✅

---







![alt text](image-3.png)
![alt text](image-2.png)
![alt text](image-1.png)
![alt text](image.png)