# MongoDB mit Kubernetes Deployment und Docker Registry - Dokumentation

## Voraussetzungen

- **Docker** installiert.
- **Kubernetes** installiert und konfiguriert.
- **MongoDB Kompass (Kompass)** installiert.
- Zugriff auf eine **Docker-Registry** (z.B. `git-registry.gibb.ch`).

---

## 1. Docker Image Erstellen und Pushen

### Dockerfile erstellen

Erstelle ein `Dockerfile` für MongoDB, das deinen Dump importiert. Ein Beispiel für das `Dockerfile`:

```Dockerfile
FROM mongo:latest

WORKDIR /data/db

COPY dump /dump

EXPOSE 27017

# MongoDB Dump importieren
CMD ["sh", "-c", "mongod --bind_ip_all --fork --logpath /var/log/mongodb.log && mongorestore --host localhost --drop --dir /dump && tail -f /dev/null"]


# Docker Image erstellen

Erstelle das Docker-Image mit folgendem Befehl:
```bash
docker build -t my-mongo-image .
```

## Docker Image taggen

Tagge das Image mit dem Namen der Docker-Registry:
```bash
docker tag my-mongo-image git-registry.gibb.ch/mha146039/m347-images:latest
```

## Image pushen

Push das Image in die Docker-Registry:
```bash
docker push git-registry.gibb.ch/mha146039/m347-images:latest
```

# MongoDB auf Kubernetes Deployen

## Kubernetes Deployment YAML erstellen

Erstelle eine `mongo-deployment.yaml` Datei für das Deployment und den Service:
```yaml
apiVersion: apps/v1
kind: Deployment
metadata:
  name: mongo-deployment
  labels:
    app: mongo
spec:
  replicas: 1
  selector:
    matchLabels:
      app: mongo
  template:
    metadata:
      labels:
        app: mongo
    spec:
      containers:
        - name: mongo
          image: git-registry.gibb.ch/mha146039/m347-images:latest
          ports:
            - containerPort: 27017
---
apiVersion: v1
kind: Service
metadata:
  name: mongo-service
spec:
  selector:
    app: mongo
  ports:
    - protocol: TCP
      port: 27017
      targetPort: 27017
  type: NodePort
```

## Deployment anwenden

Führe diesen Befehl aus, um das Deployment auf Kubernetes zu erstellen:
```bash
kubectl apply -f mongo-deployment.yaml
```

## Deployment und Service Status prüfen

Prüfe den Status des Deployments und der Pods:
```bash
kubectl get deployments
kubectl get pods
```


# MongoDB Compass - Verbindung zu MongoDB herstellen


## Kompass Download
Den Kompass kann man ganz leicht wie jedes andere Programm Herunterladen.
Die Rescouren bekommt man von der Offiziellen MongoDB seite:
Windows:
https://downloads.mongodb.com/compass/mongodb-compass-1.45.4-win32-x64.exe
Mac:
https://downloads.mongodb.com/compass/mongodb-compass-1.45.4-darwin-arm64.dmg
Linux:
https://downloads.mongodb.com/compass/mongodb-compass_1.45.4_amd64.deb


Falls man das selbst anschauen möchte oder andere Systeme hat kann man diese hier holen:
https://www.mongodb.com/try/download/compass

## MongoDB Verbindung aufbauen

Um mit MongoDB Compass eine Verbindung zu deiner MongoDB-Instanz auf Kubernetes herzustellen, benötigst du folgende Informationen:

### NodePort herausfinden

Finde den NodePort mit folgendem Befehl heraus:
```bash
kubectl get svc mongo-service
```

### Beispiel-Ausgabe:
```bash
NAME             TYPE       CLUSTER-IP      EXTERNAL-IP   PORT(S)          AGE
mongo-service    NodePort   10.107.128.1              27017:30007/TCP  2m
```

In diesem Fall ist der NodePort `30007`.

### Beispiel-Verbindungsstring

Verwende diesen Verbindungsstring, um eine Verbindung herzustellen:
```bash
mongodb://localhost:<NodePort>
```

## Verbindung in MongoDB Compass herstellen

1. Öffne MongoDB Compass.
2. Erstelle eine neue Verbindung
3. Gib unter Hostname `localhost` ein.
4. Gib unter Port den NodePort ein (z.B. `30007`).
5. Falls Authentifizierung aktiviert ist, gib Benutzername und Passwort ein.
6. Klicke auf **Connect**, um die Verbindung herzustellen.
